@@ -15,30 +15,32 @@ def _get_kwargs(
   *,
   limit: Union[Unset, int] = 50,
   offset: Union[Unset, int] = 0,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
-
   params: dict[str, Any] = {}
 
   params["limit"] = limit
 
   params["offset"] = offset
 
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
   params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "get",
-    "url": f"/v1/{graph_id}/backups",
+    "url": f"/v1/graphs/{graph_id}/backups",
     "params": params,
-    "cookies": cookies,
   }
 
   _kwargs["headers"] = headers
@@ -79,8 +81,8 @@ def sync_detailed(
   client: AuthenticatedClient,
   limit: Union[Unset, int] = 50,
   offset: Union[Unset, int] = 0,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[BackupListResponse, HTTPValidationError]]:
   """List Kuzu graph backups
 
@@ -90,8 +92,8 @@ def sync_detailed(
       graph_id (str): Graph database identifier
       limit (Union[Unset, int]): Maximum number of backups to return Default: 50.
       offset (Union[Unset, int]): Number of backups to skip Default: 0.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -105,8 +107,8 @@ def sync_detailed(
     graph_id=graph_id,
     limit=limit,
     offset=offset,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -122,8 +124,8 @@ def sync(
   client: AuthenticatedClient,
   limit: Union[Unset, int] = 50,
   offset: Union[Unset, int] = 0,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[BackupListResponse, HTTPValidationError]]:
   """List Kuzu graph backups
 
@@ -133,8 +135,8 @@ def sync(
       graph_id (str): Graph database identifier
       limit (Union[Unset, int]): Maximum number of backups to return Default: 50.
       offset (Union[Unset, int]): Number of backups to skip Default: 0.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -149,8 +151,8 @@ def sync(
     client=client,
     limit=limit,
     offset=offset,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -160,8 +162,8 @@ async def asyncio_detailed(
   client: AuthenticatedClient,
   limit: Union[Unset, int] = 50,
   offset: Union[Unset, int] = 0,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[BackupListResponse, HTTPValidationError]]:
   """List Kuzu graph backups
 
@@ -171,8 +173,8 @@ async def asyncio_detailed(
       graph_id (str): Graph database identifier
       limit (Union[Unset, int]): Maximum number of backups to return Default: 50.
       offset (Union[Unset, int]): Number of backups to skip Default: 0.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -186,8 +188,8 @@ async def asyncio_detailed(
     graph_id=graph_id,
     limit=limit,
     offset=offset,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -201,8 +203,8 @@ async def asyncio(
   client: AuthenticatedClient,
   limit: Union[Unset, int] = 50,
   offset: Union[Unset, int] = 0,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[BackupListResponse, HTTPValidationError]]:
   """List Kuzu graph backups
 
@@ -212,8 +214,8 @@ async def asyncio(
       graph_id (str): Graph database identifier
       limit (Union[Unset, int]): Maximum number of backups to return Default: 50.
       offset (Union[Unset, int]): Number of backups to skip Default: 0.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -229,7 +231,7 @@ async def asyncio(
       client=client,
       limit=limit,
       offset=offset,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
