@@ -16,21 +16,28 @@ def _get_kwargs(
   graph_id: str,
   *,
   body: CreateConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
-    "url": f"/v1/{graph_id}/connections",
-    "cookies": cookies,
+    "url": f"/v1/graphs/{graph_id}/connections",
+    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -90,8 +97,8 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: CreateConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Create Connection
 
@@ -119,8 +126,8 @@ def sync_detailed(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CreateConnectionRequest): Request to create a new connection.
 
   Raises:
@@ -134,8 +141,8 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -150,8 +157,8 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: CreateConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Create Connection
 
@@ -179,8 +186,8 @@ def sync(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CreateConnectionRequest): Request to create a new connection.
 
   Raises:
@@ -195,8 +202,8 @@ def sync(
     graph_id=graph_id,
     client=client,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -205,8 +212,8 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: CreateConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Create Connection
 
@@ -234,8 +241,8 @@ async def asyncio_detailed(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CreateConnectionRequest): Request to create a new connection.
 
   Raises:
@@ -249,8 +256,8 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -263,8 +270,8 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: CreateConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Create Connection
 
@@ -292,8 +299,8 @@ async def asyncio(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CreateConnectionRequest): Request to create a new connection.
 
   Raises:
@@ -309,7 +316,7 @@ async def asyncio(
       graph_id=graph_id,
       client=client,
       body=body,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
