@@ -15,21 +15,28 @@ def _get_kwargs(
   graph_id: str,
   connection_id: str,
   *,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "delete",
-    "url": f"/v1/{graph_id}/connections/{connection_id}",
-    "cookies": cookies,
+    "url": f"/v1/graphs/{graph_id}/connections/{connection_id}",
+    "params": params,
   }
 
   _kwargs["headers"] = headers
@@ -81,8 +88,8 @@ def sync_detailed(
   connection_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Delete Connection
 
@@ -102,8 +109,8 @@ def sync_detailed(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -116,8 +123,8 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     connection_id=connection_id,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -132,8 +139,8 @@ def sync(
   connection_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Delete Connection
 
@@ -153,8 +160,8 @@ def sync(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -168,8 +175,8 @@ def sync(
     graph_id=graph_id,
     connection_id=connection_id,
     client=client,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -178,8 +185,8 @@ async def asyncio_detailed(
   connection_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Delete Connection
 
@@ -199,8 +206,8 @@ async def asyncio_detailed(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -213,8 +220,8 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     connection_id=connection_id,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -227,8 +234,8 @@ async def asyncio(
   connection_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Delete Connection
 
@@ -248,8 +255,8 @@ async def asyncio(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -264,7 +271,7 @@ async def asyncio(
       graph_id=graph_id,
       connection_id=connection_id,
       client=client,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
