@@ -19,21 +19,28 @@ def _get_kwargs(
   connection_id: str,
   *,
   body: SyncConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
-    "url": f"/v1/{graph_id}/connections/{connection_id}/sync",
-    "cookies": cookies,
+    "url": f"/v1/graphs/{graph_id}/connections/{connection_id}/sync",
+    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -94,8 +101,8 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: SyncConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[
   Union[ErrorResponse, HTTPValidationError, SyncConnectionResponseSyncconnection]
 ]:
@@ -129,8 +136,8 @@ def sync_detailed(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SyncConnectionRequest): Request to sync a connection.
 
   Raises:
@@ -145,8 +152,8 @@ def sync_detailed(
     graph_id=graph_id,
     connection_id=connection_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -162,8 +169,8 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: SyncConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[
   Union[ErrorResponse, HTTPValidationError, SyncConnectionResponseSyncconnection]
 ]:
@@ -197,8 +204,8 @@ def sync(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SyncConnectionRequest): Request to sync a connection.
 
   Raises:
@@ -214,8 +221,8 @@ def sync(
     connection_id=connection_id,
     client=client,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -225,8 +232,8 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: SyncConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[
   Union[ErrorResponse, HTTPValidationError, SyncConnectionResponseSyncconnection]
 ]:
@@ -260,8 +267,8 @@ async def asyncio_detailed(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SyncConnectionRequest): Request to sync a connection.
 
   Raises:
@@ -276,8 +283,8 @@ async def asyncio_detailed(
     graph_id=graph_id,
     connection_id=connection_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -291,8 +298,8 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: SyncConnectionRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[
   Union[ErrorResponse, HTTPValidationError, SyncConnectionResponseSyncconnection]
 ]:
@@ -326,8 +333,8 @@ async def asyncio(
   Args:
       graph_id (str): Graph database identifier
       connection_id (str): Connection identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SyncConnectionRequest): Request to sync a connection.
 
   Raises:
@@ -344,7 +351,7 @@ async def asyncio(
       connection_id=connection_id,
       client=client,
       body=body,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
