@@ -17,21 +17,28 @@ def _get_kwargs(
   graph_id: str,
   *,
   body: Union["DataFrameCopyRequest", "S3CopyRequest", "URLCopyRequest"],
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
-    "url": f"/v1/{graph_id}/copy",
-    "cookies": cookies,
+    "url": f"/v1/graphs/{graph_id}/copy",
+    "params": params,
   }
 
   _kwargs["json"]: dict[str, Any]
@@ -102,8 +109,8 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: Union["DataFrameCopyRequest", "S3CopyRequest", "URLCopyRequest"],
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, CopyResponse, HTTPValidationError]]:
   """Copy Data to Graph
 
@@ -169,8 +176,8 @@ def sync_detailed(
   Args:
       graph_id (str): Target graph identifier (user graphs only - shared repositories not
           allowed)
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (Union['DataFrameCopyRequest', 'S3CopyRequest', 'URLCopyRequest']):
 
   Raises:
@@ -184,8 +191,8 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -200,8 +207,8 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: Union["DataFrameCopyRequest", "S3CopyRequest", "URLCopyRequest"],
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, CopyResponse, HTTPValidationError]]:
   """Copy Data to Graph
 
@@ -267,8 +274,8 @@ def sync(
   Args:
       graph_id (str): Target graph identifier (user graphs only - shared repositories not
           allowed)
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (Union['DataFrameCopyRequest', 'S3CopyRequest', 'URLCopyRequest']):
 
   Raises:
@@ -283,8 +290,8 @@ def sync(
     graph_id=graph_id,
     client=client,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -293,8 +300,8 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: Union["DataFrameCopyRequest", "S3CopyRequest", "URLCopyRequest"],
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, CopyResponse, HTTPValidationError]]:
   """Copy Data to Graph
 
@@ -360,8 +367,8 @@ async def asyncio_detailed(
   Args:
       graph_id (str): Target graph identifier (user graphs only - shared repositories not
           allowed)
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (Union['DataFrameCopyRequest', 'S3CopyRequest', 'URLCopyRequest']):
 
   Raises:
@@ -375,8 +382,8 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -389,8 +396,8 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: Union["DataFrameCopyRequest", "S3CopyRequest", "URLCopyRequest"],
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, CopyResponse, HTTPValidationError]]:
   """Copy Data to Graph
 
@@ -456,8 +463,8 @@ async def asyncio(
   Args:
       graph_id (str): Target graph identifier (user graphs only - shared repositories not
           allowed)
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (Union['DataFrameCopyRequest', 'S3CopyRequest', 'URLCopyRequest']):
 
   Raises:
@@ -473,7 +480,7 @@ async def asyncio(
       graph_id=graph_id,
       client=client,
       body=body,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
