@@ -14,21 +14,28 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
   graph_id: str,
   *,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "get",
-    "url": f"/v1/{graph_id}/analytics",
-    "cookies": cookies,
+    "url": f"/v1/graphs/{graph_id}/analytics",
+    "params": params,
   }
 
   _kwargs["headers"] = headers
@@ -79,8 +86,8 @@ def sync_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, GraphMetricsResponse, HTTPValidationError]]:
   """Get Graph Metrics
 
@@ -104,8 +111,8 @@ def sync_detailed(
 
   Args:
       graph_id (str): The graph ID to get metrics for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -117,8 +124,8 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -132,8 +139,8 @@ def sync(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, GraphMetricsResponse, HTTPValidationError]]:
   """Get Graph Metrics
 
@@ -157,8 +164,8 @@ def sync(
 
   Args:
       graph_id (str): The graph ID to get metrics for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -171,8 +178,8 @@ def sync(
   return sync_detailed(
     graph_id=graph_id,
     client=client,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -180,8 +187,8 @@ async def asyncio_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, GraphMetricsResponse, HTTPValidationError]]:
   """Get Graph Metrics
 
@@ -205,8 +212,8 @@ async def asyncio_detailed(
 
   Args:
       graph_id (str): The graph ID to get metrics for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -218,8 +225,8 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -231,8 +238,8 @@ async def asyncio(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, GraphMetricsResponse, HTTPValidationError]]:
   """Get Graph Metrics
 
@@ -256,8 +263,8 @@ async def asyncio(
 
   Args:
       graph_id (str): The graph ID to get metrics for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -271,7 +278,7 @@ async def asyncio(
     await asyncio_detailed(
       graph_id=graph_id,
       client=client,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
