@@ -15,28 +15,30 @@ def _get_kwargs(
   graph_id: str,
   *,
   include_details: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
-
   params: dict[str, Any] = {}
 
   params["include_details"] = include_details
 
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
   params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "get",
-    "url": f"/v1/{graph_id}/analytics/usage",
+    "url": f"/v1/graphs/{graph_id}/analytics/usage",
     "params": params,
-    "cookies": cookies,
   }
 
   _kwargs["headers"] = headers
@@ -84,8 +86,8 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   include_details: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, GraphUsageResponse, HTTPValidationError]]:
   """Get Usage Statistics
 
@@ -117,8 +119,8 @@ def sync_detailed(
       graph_id (str): The graph ID to get usage stats for
       include_details (Union[Unset, bool]): Include detailed metrics (may be slower) Default:
           False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -131,8 +133,8 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     include_details=include_details,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -147,8 +149,8 @@ def sync(
   *,
   client: AuthenticatedClient,
   include_details: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, GraphUsageResponse, HTTPValidationError]]:
   """Get Usage Statistics
 
@@ -180,8 +182,8 @@ def sync(
       graph_id (str): The graph ID to get usage stats for
       include_details (Union[Unset, bool]): Include detailed metrics (may be slower) Default:
           False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -195,8 +197,8 @@ def sync(
     graph_id=graph_id,
     client=client,
     include_details=include_details,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -205,8 +207,8 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   include_details: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, GraphUsageResponse, HTTPValidationError]]:
   """Get Usage Statistics
 
@@ -238,8 +240,8 @@ async def asyncio_detailed(
       graph_id (str): The graph ID to get usage stats for
       include_details (Union[Unset, bool]): Include detailed metrics (may be slower) Default:
           False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -252,8 +254,8 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     include_details=include_details,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -266,8 +268,8 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   include_details: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, GraphUsageResponse, HTTPValidationError]]:
   """Get Usage Statistics
 
@@ -299,8 +301,8 @@ async def asyncio(
       graph_id (str): The graph ID to get usage stats for
       include_details (Union[Unset, bool]): Include detailed metrics (may be slower) Default:
           False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -315,7 +317,7 @@ async def asyncio(
       graph_id=graph_id,
       client=client,
       include_details=include_details,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
