@@ -17,17 +17,13 @@ def _get_kwargs(
   body: MCPToolCall,
   format_: Union[None, Unset, str] = UNSET,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
-
   params: dict[str, Any] = {}
 
   json_format_: Union[None, Unset, str]
@@ -39,13 +35,19 @@ def _get_kwargs(
 
   params["test_mode"] = test_mode
 
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
   params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
-    "url": f"/v1/{graph_id}/mcp/call-tool",
+    "url": f"/v1/graphs/{graph_id}/mcp/call-tool",
     "params": params,
-    "cookies": cookies,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -121,8 +123,8 @@ def sync_detailed(
   body: MCPToolCall,
   format_: Union[None, Unset, str] = UNSET,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Execute MCP Tool
 
@@ -165,8 +167,8 @@ def sync_detailed(
       graph_id (str): Graph database identifier
       format_ (Union[None, Unset, str]): Response format override (json, sse, ndjson)
       test_mode (Union[Unset, bool]): Enable test mode for debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (MCPToolCall): Request model for MCP tool execution.
 
   Raises:
@@ -182,8 +184,8 @@ def sync_detailed(
     body=body,
     format_=format_,
     test_mode=test_mode,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -200,8 +202,8 @@ def sync(
   body: MCPToolCall,
   format_: Union[None, Unset, str] = UNSET,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Execute MCP Tool
 
@@ -244,8 +246,8 @@ def sync(
       graph_id (str): Graph database identifier
       format_ (Union[None, Unset, str]): Response format override (json, sse, ndjson)
       test_mode (Union[Unset, bool]): Enable test mode for debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (MCPToolCall): Request model for MCP tool execution.
 
   Raises:
@@ -262,8 +264,8 @@ def sync(
     body=body,
     format_=format_,
     test_mode=test_mode,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -274,8 +276,8 @@ async def asyncio_detailed(
   body: MCPToolCall,
   format_: Union[None, Unset, str] = UNSET,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Execute MCP Tool
 
@@ -318,8 +320,8 @@ async def asyncio_detailed(
       graph_id (str): Graph database identifier
       format_ (Union[None, Unset, str]): Response format override (json, sse, ndjson)
       test_mode (Union[Unset, bool]): Enable test mode for debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (MCPToolCall): Request model for MCP tool execution.
 
   Raises:
@@ -335,8 +337,8 @@ async def asyncio_detailed(
     body=body,
     format_=format_,
     test_mode=test_mode,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -351,8 +353,8 @@ async def asyncio(
   body: MCPToolCall,
   format_: Union[None, Unset, str] = UNSET,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Execute MCP Tool
 
@@ -395,8 +397,8 @@ async def asyncio(
       graph_id (str): Graph database identifier
       format_ (Union[None, Unset, str]): Response format override (json, sse, ndjson)
       test_mode (Union[Unset, bool]): Enable test mode for debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (MCPToolCall): Request model for MCP tool execution.
 
   Raises:
@@ -414,7 +416,7 @@ async def asyncio(
       body=body,
       format_=format_,
       test_mode=test_mode,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
