@@ -18,17 +18,13 @@ def _get_kwargs(
   mode: Union[None, ResponseMode, Unset] = UNSET,
   chunk_size: Union[Unset, int] = 1000,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
-
   params: dict[str, Any] = {}
 
   json_mode: Union[None, Unset, str]
@@ -44,13 +40,19 @@ def _get_kwargs(
 
   params["test_mode"] = test_mode
 
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
   params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
-    "url": f"/v1/{graph_id}/query",
+    "url": f"/v1/graphs/{graph_id}/query",
     "params": params,
-    "cookies": cookies,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -117,8 +119,8 @@ def sync_detailed(
   mode: Union[None, ResponseMode, Unset] = UNSET,
   chunk_size: Union[Unset, int] = 1000,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, HTTPValidationError]]:
   """Execute Cypher Query
 
@@ -175,8 +177,8 @@ def sync_detailed(
       mode (Union[None, ResponseMode, Unset]): Response mode override
       chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -193,8 +195,8 @@ def sync_detailed(
     mode=mode,
     chunk_size=chunk_size,
     test_mode=test_mode,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -212,8 +214,8 @@ def sync(
   mode: Union[None, ResponseMode, Unset] = UNSET,
   chunk_size: Union[Unset, int] = 1000,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, HTTPValidationError]]:
   """Execute Cypher Query
 
@@ -270,8 +272,8 @@ def sync(
       mode (Union[None, ResponseMode, Unset]): Response mode override
       chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -289,8 +291,8 @@ def sync(
     mode=mode,
     chunk_size=chunk_size,
     test_mode=test_mode,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -302,8 +304,8 @@ async def asyncio_detailed(
   mode: Union[None, ResponseMode, Unset] = UNSET,
   chunk_size: Union[Unset, int] = 1000,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, HTTPValidationError]]:
   """Execute Cypher Query
 
@@ -360,8 +362,8 @@ async def asyncio_detailed(
       mode (Union[None, ResponseMode, Unset]): Response mode override
       chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -378,8 +380,8 @@ async def asyncio_detailed(
     mode=mode,
     chunk_size=chunk_size,
     test_mode=test_mode,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -395,8 +397,8 @@ async def asyncio(
   mode: Union[None, ResponseMode, Unset] = UNSET,
   chunk_size: Union[Unset, int] = 1000,
   test_mode: Union[Unset, bool] = False,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, HTTPValidationError]]:
   """Execute Cypher Query
 
@@ -453,8 +455,8 @@ async def asyncio(
       mode (Union[None, ResponseMode, Unset]): Response mode override
       chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -473,7 +475,7 @@ async def asyncio(
       mode=mode,
       chunk_size=chunk_size,
       test_mode=test_mode,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
