@@ -15,21 +15,28 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
   graph_id: str,
   *,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "get",
-    "url": f"/v1/{graph_id}/schema/info",
-    "cookies": cookies,
+    "url": f"/v1/graphs/{graph_id}/schema/info",
+    "params": params,
   }
 
   _kwargs["headers"] = headers
@@ -80,8 +87,8 @@ def sync_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[
   Union[Any, GetGraphSchemaInfoResponseGetgraphschemainfo, HTTPValidationError]
 ]:
@@ -101,8 +108,8 @@ def sync_detailed(
 
   Args:
       graph_id (str): The graph database to get schema for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -114,8 +121,8 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -129,8 +136,8 @@ def sync(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[
   Union[Any, GetGraphSchemaInfoResponseGetgraphschemainfo, HTTPValidationError]
 ]:
@@ -150,8 +157,8 @@ def sync(
 
   Args:
       graph_id (str): The graph database to get schema for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -164,8 +171,8 @@ def sync(
   return sync_detailed(
     graph_id=graph_id,
     client=client,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -173,8 +180,8 @@ async def asyncio_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[
   Union[Any, GetGraphSchemaInfoResponseGetgraphschemainfo, HTTPValidationError]
 ]:
@@ -194,8 +201,8 @@ async def asyncio_detailed(
 
   Args:
       graph_id (str): The graph database to get schema for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -207,8 +214,8 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -220,8 +227,8 @@ async def asyncio(
   graph_id: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[
   Union[Any, GetGraphSchemaInfoResponseGetgraphschemainfo, HTTPValidationError]
 ]:
@@ -241,8 +248,8 @@ async def asyncio(
 
   Args:
       graph_id (str): The graph database to get schema for
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -256,7 +263,7 @@ async def asyncio(
     await asyncio_detailed(
       graph_id=graph_id,
       client=client,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
