@@ -15,21 +15,28 @@ def _get_kwargs(
   graph_id: str,
   *,
   body: SchemaValidationRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
-    "url": f"/v1/{graph_id}/schema/validate",
-    "cookies": cookies,
+    "url": f"/v1/graphs/{graph_id}/schema/validate",
+    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -85,8 +92,8 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: SchemaValidationRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, SchemaValidationResponse]]:
   """Validate Schema
 
@@ -115,8 +122,8 @@ def sync_detailed(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SchemaValidationRequest): Request model for schema validation.
 
   Raises:
@@ -130,8 +137,8 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -146,8 +153,8 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: SchemaValidationRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, SchemaValidationResponse]]:
   """Validate Schema
 
@@ -176,8 +183,8 @@ def sync(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SchemaValidationRequest): Request model for schema validation.
 
   Raises:
@@ -192,8 +199,8 @@ def sync(
     graph_id=graph_id,
     client=client,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -202,8 +209,8 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: SchemaValidationRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, SchemaValidationResponse]]:
   """Validate Schema
 
@@ -232,8 +239,8 @@ async def asyncio_detailed(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SchemaValidationRequest): Request model for schema validation.
 
   Raises:
@@ -247,8 +254,8 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -261,8 +268,8 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: SchemaValidationRequest,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, SchemaValidationResponse]]:
   """Validate Schema
 
@@ -291,8 +298,8 @@ async def asyncio(
 
   Args:
       graph_id (str): Graph database identifier
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
       body (SchemaValidationRequest): Request model for schema validation.
 
   Raises:
@@ -308,7 +315,7 @@ async def asyncio(
       graph_id=graph_id,
       client=client,
       body=body,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
