@@ -13,21 +13,28 @@ from ...types import UNSET, Response, Unset
 def _get_kwargs(
   repository: str,
   *,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
   if not isinstance(authorization, Unset):
     headers["authorization"] = authorization
 
-  cookies = {}
-  if auth_token is not UNSET:
-    cookies["auth-token"] = auth_token
+  params: dict[str, Any] = {}
+
+  json_token: Union[None, Unset, str]
+  if isinstance(token, Unset):
+    json_token = UNSET
+  else:
+    json_token = token
+  params["token"] = json_token
+
+  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": f"/v1/user/subscriptions/shared-repositories/credits/{repository}",
-    "cookies": cookies,
+    "params": params,
   }
 
   _kwargs["headers"] = headers
@@ -72,8 +79,8 @@ def sync_detailed(
   repository: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, HTTPValidationError, RepositoryCreditsResponse]]:
   """Get Repository Credits
 
@@ -81,8 +88,8 @@ def sync_detailed(
 
   Args:
       repository (str):
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -94,8 +101,8 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     repository=repository,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = client.get_httpx_client().request(
@@ -109,8 +116,8 @@ def sync(
   repository: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, HTTPValidationError, RepositoryCreditsResponse]]:
   """Get Repository Credits
 
@@ -118,8 +125,8 @@ def sync(
 
   Args:
       repository (str):
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -132,8 +139,8 @@ def sync(
   return sync_detailed(
     repository=repository,
     client=client,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   ).parsed
 
 
@@ -141,8 +148,8 @@ async def asyncio_detailed(
   repository: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, HTTPValidationError, RepositoryCreditsResponse]]:
   """Get Repository Credits
 
@@ -150,8 +157,8 @@ async def asyncio_detailed(
 
   Args:
       repository (str):
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -163,8 +170,8 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     repository=repository,
+    token=token,
     authorization=authorization,
-    auth_token=auth_token,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -176,8 +183,8 @@ async def asyncio(
   repository: str,
   *,
   client: AuthenticatedClient,
+  token: Union[None, Unset, str] = UNSET,
   authorization: Union[None, Unset, str] = UNSET,
-  auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, HTTPValidationError, RepositoryCreditsResponse]]:
   """Get Repository Credits
 
@@ -185,8 +192,8 @@ async def asyncio(
 
   Args:
       repository (str):
+      token (Union[None, Unset, str]): JWT token for SSE authentication
       authorization (Union[None, Unset, str]):
-      auth_token (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -200,7 +207,7 @@ async def asyncio(
     await asyncio_detailed(
       repository=repository,
       client=client,
+      token=token,
       authorization=authorization,
-      auth_token=auth_token,
     )
   ).parsed
